jQuery(document).ready(function($) {
    // Reset form function to maintain consistency
    function resetForm() {
        const $form = $('#easy-contact-form');
        $form.show();
        $('.success-message').remove();
        $form[0].reset();
    }

    // Form submission handler
    $('#easy-contact-form').on('submit', function(e) {
        e.preventDefault();
        
        var $form = $(this);
        var $submit = $form.find('button[type="submit"]');
        var originalText = $submit.text();
        var successColor = $('#easy-contact-popup').data('success-color') || '#4CAF50';
        
        // Disable submit button and show loading state
        $submit.prop('disabled', true).text('Sending...');

        $.ajax({
            url: easyContactPopup.ajaxurl,
            type: 'POST',
            data: {
                action: 'easy_contact_submit',
                nonce: easyContactPopup.nonce,
                name: $form.find('[name="name"]').val(),
                email: $form.find('[name="email"]').val(),
                message: $form.find('[name="message"]').val()
            },
            success: function(response) {
                if (response.success) {
                    // Show success message with custom color
                    $form.hide().after('<div class="success-message" style="color: ' + response.data.success_color + '">' + response.data.message + '</div>');
                    
                    // Reset and close after delay
                    setTimeout(function() {
                        $('#easy-contact-popup').fadeOut(function() {
                            resetForm();
                            $submit.prop('disabled', false).text(originalText);
                        });
                    }, 2000);
                } else {
                    alert(response.data.message || 'An error occurred. Please try again.');
                    $submit.prop('disabled', false).text(originalText);
                }
            },
            error: function() {
                alert('An error occurred. Please try again.');
                $submit.prop('disabled', false).text(originalText);
            }
        });
    });

    // Open popup when clicking trigger
    $('.easy-contact-trigger a').on('click', function(e) {
        e.preventDefault();
        resetForm();
        $('#easy-contact-popup').fadeIn();
    });

    // Close popup when clicking X or outside
    $('.popup-close, .popup-overlay').on('click', function(e) {
        if (e.target === this || $(e.target).hasClass('popup-close')) {
            $('#easy-contact-popup').fadeOut();
            resetForm();
        }
    });

    // Close on escape key
    $(document).on('keyup', function(e) {
        if (e.key === "Escape") {
            $('#easy-contact-popup').fadeOut();
            resetForm();
        }
    });
});